@@ -2,10 +2,10 @@ import pytest
 from pathlib import Path
 import os
 
-from ..src.openize.markitdown.converters import WordConverter, PDFConverter, ExcelConverter, PowerPointConverter
-from ..src.openize.markitdown.factory import ConverterFactory
-from ..src.openize.markitdown.llm_strategy import SaveLocally, LLMFactory, OpenAIClient, ClaudeClient
-from ..src.openize.markitdown.processor import DocumentProcessor
+from openize.markitdown.converters import WordConverter, PDFConverter, ExcelConverter, PowerPointConverter
+from openize.markitdown.factory import ConverterFactory
+from openize.markitdown.llm_strategy import SaveLocally, LLMFactory, OpenAIClient, ClaudeClient,MistralClient, GeminiClient
+from openize.markitdown.processor import DocumentProcessor
 
 
 @pytest.fixture
@@ -60,14 +60,14 @@ def test_insert_into_llm_openai(mocker, sample_md_file):
     mocker.patch("openai.ChatCompletion.create", return_value={
         "choices": [{"message": {"content": "Mocked OpenAI Response"}}]
     })
-    strategy = OpenAIClient(provider="openai")
+    strategy = OpenAIClient()
     strategy.process(sample_md_file)
 
 def test_insert_into_llm_claude(mocker, sample_md_file):
     mock_anthropic = mocker.patch("openize.markitdown.llm_strategy.Anthropic")
     mock_client = mock_anthropic.return_value
     mock_client.messages.create.return_value.content = "Mocked Claude Response"
-    strategy = ClaudeClient(provider="claude")
+    strategy = ClaudeClient()
     strategy.process(sample_md_file)
 
 
@@ -76,7 +76,7 @@ def test_insert_into_llm_claude(mocker, sample_md_file):
 def test_document_processor_local_conversion(mocker, sample_output_dir):
     mock_converter = mocker.patch("openize.markitdown.factory.ConverterFactory.get_converter", return_value=WordConverter())
     processor = DocumentProcessor(output_dir=sample_output_dir)
-    processor.process_document("sample.docx", insert_into_llm=False)
+    processor.process_document("test_input/sample.docx", insert_into_llm=False)
     output_file = sample_output_dir / "sample.md"
     assert output_file.exists()
 
@@ -85,8 +85,8 @@ def test_document_processor_with_llm_openai(mocker, sample_output_dir):
     mocker.patch("openai.ChatCompletion.create", return_value={
         "choices": [{"message": {"content": "LLM Output"}}]
     })
-    processor = DocumentProcessor(output_dir=sample_output_dir)
-    processor.process_document("sample.docx", insert_into_llm=True, llm_provider="openai")
+    processor = DocumentProcessor(output_dir=sample_output_dir, llm_client_name="openai")
+    processor.process_document("test_input/sample.docx", insert_into_llm=True)
     output_file = sample_output_dir / "sample.md"
     assert output_file.exists()
 
@@ -95,8 +95,44 @@ def test_document_processor_with_llm_claude(mocker, sample_output_dir):
     mock_anthropic = mocker.patch("openize.markitdown.llm_strategy.Anthropic")
     mock_client = mock_anthropic.return_value
     mock_client.messages.create.return_value.content = "LLM Claude Output"
-    processor = DocumentProcessor(output_dir=sample_output_dir)
-    processor.process_document("sample.docx", insert_into_llm=True, llm_provider="claude")
+    processor = DocumentProcessor(output_dir=sample_output_dir, llm_client_name="claude")
+    processor.process_document("test_input/sample.docx", insert_into_llm=True)
     output_file = sample_output_dir / "sample.md"
     assert output_file.exists()
 
+def test_insert_into_llm_gemini(mocker, sample_md_file):
+    mock_response = mocker.Mock()
+    mock_response.raise_for_status.return_value = None
+    mock_response.json.return_value = {
+        "candidates": [
+            {"content": {"parts": [{"text": "Mocked Gemini Response"}]}}
+        ]
+    }
+
+    mocker.patch("requests.post", return_value=mock_response)
+    mocker.patch.dict(os.environ, {
+        "GEMINI_API_KEY": "dummy_key",
+        "GEMINI_MODEL": "gemini-pro"
+    })
+
+    client = GeminiClient()
+    client.process(sample_md_file)
+def test_insert_into_llm_mistral(mocker, sample_md_file):
+    mock_response = mocker.Mock()
+    mock_response.raise_for_status.return_value = None
+    mock_response.json.return_value = {
+        "choices": [
+            {"message": {"content": "Mocked Mistral Response"}}
+        ]
+    }
+
+    mocker.patch("requests.post", return_value=mock_response)
+    mocker.patch.dict(os.environ, {
+        "MISTRAL_API_KEY": "dummy_key",
+        "MISTRAL_MODEL": "mistral-medium"
+    })
+
+    client = MistralClient()
+    client.process(sample_md_file)
+
+
